commit/cc-mode: 2 new changesets
11 years, 11 months
Bitbucket
2 new commits in cc-mode:
https://bitbucket.org/xemacs/cc-mode/commits/ea4257fccf9b/
changeset: ea4257fccf9b
user: acm
date: 2013-01-17 21:06:14
summary: Fix bugs in the state cache. Enhance a debugging mechanism.
cc-engine.el (c-state-old-cpp-beg-marker, c-state-old-cpp-end-marker):
New variables.
(c-parse-state-get-strategy): Don't use "brace at column zero" strategy
for C++.
(c-append-lower-brace-pair-to-state-cache): Repair algorithm. Start a
backward search for "}" definitively outside CPP constructs.
(c-remove-stale-state-cache): Inform the caller of a need to search back
for a brace pair in certain circumstances.
(c-state-maybe-marker): New macro.
(c-parse-state): Reuse markers when appropriate.
(c-parse-state-point): New variable.
(c-record-parse-state-state): Record old parse state with `copy-tree'.
Record previous value of point.
(c-replay-parse-state-state): Replay markers more correctly.
(c-debug-parse-state-double-cons): New debugging function.
(c-debug-parse-state): Call the above new function.
(c-toggle-parse-state-debug): Output a confirmatory message.
cc-mode.el (c-before-change, c-after-change): Call
c-invalidate-state-cache from `c-before-change' instead of
`c-after-change'.
affected #: 2 files
diff -r e6f8eb00235954a871e6f44c161e09d34cd2af69 -r ea4257fccf9b3cbe323b3b04323c083096dabd70 cc-mode.el
--- a/cc-mode.el
+++ b/cc-mode.el
@@ -1058,7 +1058,10 @@
(mapc (lambda (fn)
(funcall fn beg end))
c-get-state-before-change-functions))
- )))))
+ )))
+ ;; The following must be done here rather than in `c-after-change' because
+ ;; newly inserted parens would foul up the invalidation algorithm.
+ (c-invalidate-state-cache beg)))
(defvar c-in-after-change-fontification nil)
(make-variable-buffer-local 'c-in-after-change-fontification)
@@ -1108,7 +1111,7 @@
(c-trim-found-types beg end old-len) ; maybe we don't need all of these.
(c-invalidate-sws-region-after beg end)
- (c-invalidate-state-cache beg)
+ ;; (c-invalidate-state-cache beg) ; moved to `c-before-change'.
(c-invalidate-find-decl-cache beg)
(when c-recognize-<>-arglists
https://bitbucket.org/xemacs/cc-mode/commits/2b353db0dc37/
changeset: 2b353db0dc37
user: acm
date: 2013-01-17 22:08:49
summary: Merge.
affected #: 3 files
diff -r ea4257fccf9b3cbe323b3b04323c083096dabd70 -r 2b353db0dc37b60febfd99f3fbb796f2fd4e24f6 .hgtags
--- a/.hgtags
+++ b/.hgtags
@@ -91,3 +91,4 @@
2475272d8bae991446e6b5fe927fb9a489b6df5d cc-mode-1_56
a9aff1813e2a4aa3d8af1ae40b69bcaf033f7905 cc-mode-1_57
46f8e9f7f8174bdf529daf1577892b212c566d5b cc-mode-1_58
+c325532f7d0bbf9c4cae63da83d12abf2033c6b5 cc-mode-1_59
diff -r ea4257fccf9b3cbe323b3b04323c083096dabd70 -r 2b353db0dc37b60febfd99f3fbb796f2fd4e24f6 ChangeLog
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2012-12-28 Norbert Koch <viteno(a)xemacs.org>
+
+ * Makefile (VERSION): XEmacs package 1.59 released.
+
2012-12-10 Norbert Koch <viteno(a)xemacs.org>
* Makefile (VERSION): XEmacs package 1.58 released.
diff -r ea4257fccf9b3cbe323b3b04323c083096dabd70 -r 2b353db0dc37b60febfd99f3fbb796f2fd4e24f6 Makefile
--- a/Makefile
+++ b/Makefile
@@ -17,7 +17,7 @@
# the Free Software Foundation, Inc., 59 Temple Place - Suite 330,
# Boston, MA 02111-1307, USA.
-VERSION = 1.58
+VERSION = 1.59
AUTHOR_VERSION = 5.32.2
MAINTAINER = Alan Mackenzie <bug-cc-mode(a)gnu.org>
PACKAGE = cc-mode
Repository URL: https://bitbucket.org/xemacs/cc-mode/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://lists.xemacs.org/mailman/listinfo/xemacs-patches
Re: Issue 802: menubar-x.c assertion failure
11 years, 11 months
Jerry James
On Wed, Jan 16, 2013 at 4:05 PM, Mats Lidell <matsl(a)xemacs.org> wrote:
> If a bug in a menu specification can cause this then it should, as you
> suggest, handle it gracefully. +1
Okay, I propose this patch. If nobody objects, I will commit it in a
day or two. Hmmm, upon looking at my changelog entry again, I can
suddenly hear Jeff Lynne singing, "Don't bring me down..."
diff -r 8b5bdc8aebfd src/ChangeLog
--- a/src/ChangeLog Sat Jan 05 02:11:23 2013 +0900
+++ b/src/ChangeLog Wed Jan 16 16:45:51 2013 -0700
@@ -1,3 +1,9 @@
+2013-01-16 Jerry James <james(a)xemacs.org>
+
+ * menubar-x.c (set_frame_menubar): when a menubar specification has an
+ error, don't fail an assert() and bring XEmacs down. Instead, return
+ 0 to just skip the faulty menu and show any errors in *Warnings*.
+
2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
* XEmacs 21.5.33 "horseradish" is released.
diff -r 8b5bdc8aebfd src/menubar-x.c
--- a/src/menubar-x.c Sat Jan 05 02:11:23 2013 +0900
+++ b/src/menubar-x.c Wed Jan 16 16:45:51 2013 -0700
@@ -573,7 +573,8 @@
menubar_visible = !NILP (w->menubar_visible_p);
data = compute_menubar_data (f, menubar, deep_p);
- assert (data && (data->next || data->contents));
+ if (!data || (!data->next && !data->contents))
+ return 0;
if (!FRAME_X_MENUBAR_ID (f))
FRAME_X_MENUBAR_ID (f) = new_lwlib_id ();
--
Jerry James
http://www.jamezone.org/
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://lists.xemacs.org/mailman/listinfo/xemacs-patches
commit/xemacsweb: stephen_at_xemacs: Add Changes Summary.
11 years, 11 months
Bitbucket
1 new commit in xemacsweb:
https://bitbucket.org/xemacs/xemacsweb/commits/d41e1ffd27fc/
changeset: d41e1ffd27fc
user: stephen_at_xemacs
date: 2013-01-04 19:10:23
summary: Add Changes Summary.
affected #: 1 file
diff -r 7ed89624423a0e658cd4313aba8a71acb5f37db2 -r d41e1ffd27fc990d47f475cf0b12e40ae4ff70dc Releases/21.5.33.content
--- a/Releases/21.5.33.content
+++ b/Releases/21.5.33.content
@@ -92,6 +92,59 @@
<p>goto <a href="#announcement">announcement</a>, summary,
<a href="#changes">changes</a></p>
+<pre xml:space="preserve">
+Major Features, Bugfixes, and Backward Incompatible Changes
+
+-- Nothing major this time. -- nobody
+
+User-Visible Bug Fixes and Improvements
+
+-- Improve: Reorganize default menubar. -- Stephen J. Turnbull
+
+Build Infrastructure and Source Tree
+
+-- Fix: Prevent make distclean from deleting configure in modules. -- Mats Lidell
+-- Improve: Make configure warn about missing system package hierarchies. -- Stephen J. Turnbull
+
+Documentation
+
+-- Fix: Description of Mercurial repositories. -- Stephen J. Turnbull
+-- Fix: TUTORIAL to describe recenter-top-bottom correctly. -- Mats Lidell
+-- Improve: Description of `mark-defun'. -- Steven Mitchell
+-- Improve: Documentation of menus. -- Byrel Mitchell, Vin Shelton
+-- Improve: INSTALL. -- Steven Mitchell, Stephen J. Turnbull, Robert D. Royar
+
+Lisp API
+
+-- Fix: Implement :active in submenu specs. -- Byrel Mitchell
+-- New: Adopt GNU's ## syntax for the interned symbol with the zero-length name. -- Aidan Kehoe
+-- New: Command remapping in keymaps from GNU. -- Aidan Kehoe
+-- New: call-process-shell-command from GNU. -- Mats Lidell
+-- New: delete-trailing-lines, delete-trailing-whitespace from GNU. -- Aidan Kehoe
+-- New: recenter-positions, recenter-top-bottom, recenter-last-op from GNU. -- Mats Lidell
+-- Improve: Accept GNU's UNIVERSAL argument in format-time-string. -- Aidan Kehoe
+-- Improve: Allow noninteractive call of self-insert-command with null count. -- Stephen J. Turnbull
+
+Internal API and Implementation
+
+-- Fix: Avoid malloc'ing inside search. -- Aidan Kehoe
+-- Fix: GCPRO etc in define-specifier-tag. -- Aidan Kehoe
+-- Fix: Incorrect handling of empty sets in subsetp. -- Stephen J. Turnbull, Benson Mitchell, Steven Mitchell
+-- Fix: Inhibit error at compile time in equal, member, assoc, rassoc. -- Aidan Kehoe
+-- Fix: Regexp in describe-register-1. -- Stephen Turnbull, Mats Lidell
+-- Fix: Respect face and display table information in the minibuffer prompt. -- Aidan Kehoe
+-- Improve: Charset not in table warning message. -- Stephen J. Turnbull
+-- Improve: find-coding-system-magic-cookie-in-file moved to C. -- Aidan Kehoe
+
+Testing and Debugging
+
+-- New: Simple test cases for call-process-shell-command. -- Mats Lidell
+-- New: Test regular expression in describe-register-1. -- Mats Lidell
+-- New: Test search for character ranges with dirty syntax table. -- Aidan Kehoe
+-- New: Test the new command remapping functionality. -- Aidan Kehoe
+-- New: Tests of #'subsetp. -- Stephen J. Turnbull, Steven Mitchell, Benson Mitchell
+</pre>
+
<h1><a name="changes">ChangeLogs</a> for XEmacs 21.5.33 "horseradish"</h1><p>goto <a href="#announcement">announcement</a>,
<a href="#summary">summary</a>,
Repository URL: https://bitbucket.org/xemacs/xemacsweb/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://lists.xemacs.org/mailman/listinfo/xemacs-patches
commit/xemacsweb: stephen_at_xemacs: XEmacs 21.5.33 is released.
11 years, 11 months
Bitbucket
1 new commit in xemacsweb:
https://bitbucket.org/xemacs/xemacsweb/commits/7ed89624423a/
changeset: 7ed89624423a
user: stephen_at_xemacs
date: 2013-01-04 18:43:43
summary: XEmacs 21.5.33 is released.
affected #: 3 files
diff -r 09422ac55723e3570603f1cc304642289dd21dd0 -r 7ed89624423a0e658cd4313aba8a71acb5f37db2 Releases/21.5.33.content
--- /dev/null
+++ b/Releases/21.5.33.content
@@ -0,0 +1,560 @@
+%title%
+XEmacs 21.5.33 "horseradish" is released
+%author%
+automatically generated (with release announcement) by xre.py
+%main%
+ <h1><a name="announcement">XEmacs 21.5.33 "horseradish" is released</a></h1>
+ <p>goto announcement,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+To: xemacs-beta(a)xemacs.org
+From: "Stephen J. Turnbull, XEmacs 21.5 Beta Engineer" <stephen(a)xemacs.org>
+Subject: XEmacs 21.5.33 "horseradish" is released.
+Organization: The XEmacs Project
+
+
+
+* XEmacs 21.5.33 "horseradish" is released.
+ "horseradish" is the thirty-fourth in the VEGETABLE series.
+
+
+The successor to XEmacs 21.5.32 "habanero", "horseradish" adds a few
+minor fixes and improvements. The Help menu has been reorganized, and
+there have been a number of syncs to GNU Emacs which are mostly useful
+for supporting syncs of specific packages. The most generally useful
+improvement is probably new support for the [remap] syntax in `define-key'.
+
+This is the development line. The current series started with XEmacs
+21.5.0 (an alias for XEmacs 21.4.0 "Solid Vapor", the first release in
+the current stable line). 21.5 is the code base for introduction of
+major new subsystems and fixes to design bugs that experience shows will
+introduce instability. So far the main effort has been on improved
+support for Unicode, updates to the build infrastructure, and development
+of new features in memory allocation.
+
+For general information about XEmacs, the developers, and the user
+community, see our home page,
+
+ http://www.xemacs.org/
+
+* XEmacs 21.5.33 is "beta" software.
+
+The usual "no warranty" disclaimer (see etc/COPYING, sections 10 and 11)
+applies. At this point in time, it is the version that most developers
+are using for their daily work. However, it is certain that many bugs
+remain and new ones will be introduced as development proceeds. Be sure
+to take care to safe your work often and follow a regular backup regime.
+
+* Availability
+
+Anonymous ftp:
+
+ ftp://ftp.xemacs.org/pub/xemacs/xemacs-21.5
+
+See http://www.xemacs.org/Install/ for more information about building
+from source.
+
+If you already have a 21.5.32 source tree, a patchkit is available in
+xemacs-21.5.32-21.5.33.patch.gz. This does not update .elcs or .infos.
+They will be rebuilt when you make XEmacs. If you have an earlier
+version, you can repeatedly apply patchkits.
+
+Also, if you don't have the packages yet, see
+
+ http://www.xemacs.org/Documentation/packageGuide.html.
+
+Mercurial repository:
+
+ http://hg.debian.org/hg/xemacs/xemacs-beta
+
+This is a read-only Mercurial repository. To check out XEmacs 21.5.33,
+use the command
+
+ hg clone %(releaseSpec) http://hg.debian.org/hg/xemacs/xemacs-beta
+
+to create a new Mercurial workspace, or
+
+ hg pull -u %(releaseSpec)
+
+if you already have a local workspace from Mercurial. To update to the
+most recent commits to the official repository, use
+
+ hg pull -u tip
+
+For more details, see
+
+ http://www.xemacs.org/Develop/hgaccess.html .
+
+</pre>
+
+ <h1><a name="summary">Changes</a> in XEmacs 21.5.33 "horseradish"</h1>
+ <p>goto <a href="#announcement">announcement</a>, summary,
+ <a href="#changes">changes</a></p>
+
+ <h1><a name="changes">ChangeLogs</a> for XEmacs 21.5.33 "horseradish"</h1>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ changes</p>
+ <ul>
+ <li>ChangeLog Entries from <a href="#ChangeLog">ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#etc:ChangeLog">etc/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#lib-src:ChangeLog">lib-src/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#lisp:ChangeLog">lisp/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#lwlib:ChangeLog">lwlib/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#man:ChangeLog">man/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#netinstall:ChangeLog">netinstall/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#nt:ChangeLog">nt/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#src:ChangeLog">src/ChangeLog</a></li>
+ <li>ChangeLog Entries from <a href="#tests:ChangeLog">tests/ChangeLog</a></li>
+ </ul>
+
+ <h2>ChangeLog Entries from <a name="ChangeLog">ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2012-12-27 Robert D. Royar <xemacs(a)royar.org>
+
+ Minor additions by Stephen J. Turnbull <stephen(a)xemacs.org>.
+
+ * INSTALL: correct typographical errors; update
+ version numbers provided in Running Make section;
+ change default datadir reference to /usr/local/share
+ to match all other references to datadir's subdirectories;
+ change "can not" to "cannot".
+
+2012-11-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * INSTALL: Reorganize and update.
+ Thanks to Steven Mitchell for the suggestion.
+
+2012-08-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * configure.ac (Package Search): New Installation section.
+ Warn about missing system package hierarchies.
+
+ * configure: Regenerate.</pre>
+
+ <h2>ChangeLog Entries from <a name="etc:ChangeLog">etc/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2012-09-18 Mats Lidell <matsl(a)xemacs.org>
+
+ * TUTORIAL: Updated due to recenter-top-bottom</pre>
+
+ <h2>ChangeLog Entries from <a name="lib-src:ChangeLog">lib-src/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.</pre>
+
+ <h2>ChangeLog Entries from <a name="lisp:ChangeLog">lisp/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2012-12-28 Byrel Mitchell <byrel.mitchell(a)gmail.com>
+
+ * menubar.el (check-menu-syntax): Implement :active in submenu specs.
+
+2012-08-03 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * menubar-items.el (default-menubar): Reorganize.
+ Add PROBLEMS to toplevel.
+ New "More about XEmacs" submenu for NEWS, licensing, etc.
+ New "Recent History" menu for messages, lossage, etc.
+ Get rid of ugly and unexpressive ellipses.
+
+2012-12-14 Mats Lidell <matsl(a)xemacs.org>
+
+ * register.el (describe-register-1): Fix erroneous regular
+ expression. Thank you Stephen Turnbull.
+
+2012-11-06 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * cl-macs.el (equal, member, assoc, rassoc):
+ Never error at compile time in these compiler macros because of an
+ incorrect number of arguments.
+
+2012-10-14 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * help.el:
+ * help.el (describe-function-1):
+ Add some newlines here when dealing with remapped commands, thank
+ you Robert Pluim.
+
+2012-10-13 Mats Lidell <matsl(a)xemacs.org>
+
+ * process.el (call-process-shell-command): New function from GNU.
+
+2012-09-18 Mats Lidell <matsl(a)xemacs.org>
+
+ * window-xemacs.el (recenter-positions): New defcustom.
+ (recenter-top-bottom): New command.
+ (recenter-last-op): New defvar.
+
+ * replace.el (perform-replace): Let-bind recenter-last-op to nil.
+ For def=recenter, replace `recenter' with `recenter-top-bottom'
+ that is called with `this-command' and `last-command' let-bound to
+ `recenter-top-bottom'. When the last `def' was not `recenter',
+ set `recenter-last-op' to nil.
+
+ * keydefs.el (global-map): Make recenter-top-bottom new default
+ for C-l.
+
+2012-09-08 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * simple.el:
+ * simple.el (delete-trailing-lines): New.
+ * simple.el (delete-trailing-whitespace): New.
+ Import this function and an associated variable from GNU, thank
+ you GNU.
+ Update its interactive spec to work correctly in XEmacs.
+
+2012-09-07 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * files.el:
+ * files.el (find-coding-system-magic-cookie-in-file):
+ Removed. Move this to C, so we can use
+ look_for_coding_system_magic_cookie().
+
+2012-09-02 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * help.el (describe-function-1):
+ Document any command remapping that has been done in this function.</pre>
+
+ <h2>ChangeLog Entries from <a name="lwlib:ChangeLog">lwlib/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.</pre>
+
+ <h2>ChangeLog Entries from <a name="man:ChangeLog">man/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2013-01-02 Vin Shelton <acs(a)xemacs.org>
+
+ * lispref/menus.texi (Creating Menu Accelerators): Clarify that
+ the menu accelerator must be lowercase.
+
+2012-12-28 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * xemacs/programs.texi (Defuns): Improve description of `mark-defun'.
+ Thanks to Steven Mitchell for the suggestion.
+
+2012-12-28 Byrel Mitchell <byrel.mitchell(a)gmail.com>
+
+ * lispref/menus.texi (Menu Format):
+ Document use of :active in submenu specs.
+
+2012-12-28 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * internals/internals.texi (Mercurial Basics):
+ Update references to repository to reflect current reality.
+
+2012-12-28 Byrel Mitchell <byrel.mitchell(a)gmail.com>
+
+ * lispref/menus.texi (Creating Menu Accelerators): Typo fix.
+
+2012-10-13 Mats Lidell <matsl(a)xemacs.org>
+
+ * lispref/processes.texi (Synchronous Processes): New function
+ call-process-shell-command.
+
+2012-09-18 Mats Lidell <matsl(a)xemacs.org>
+
+ * lispref/windows.texi (Vertical Scrolling): Added
+ recenter-top-bottom and recenter-positions
+
+ * xemacs/display.texi (Display): Rearranged and added
+ documentation due to new function recenter-top-bottom.
+
+2012-08-06 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * lispref/symbols.texi (Symbol Components):
+ Document the new syntax of ## for the symbol with name "" interned
+ in obarray.
+
+2012-09-02 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * lispref/keymaps.texi (Keymaps):
+ * lispref/keymaps.texi (Changing Key Bindings):
+ * lispref/keymaps.texi (Scanning Keymaps):
+ * lispref/keymaps.texi (Remapping commands):
+ * lispref/keymaps.texi (XEmacs): New.
+ * lispref/keymaps.texi (Other Keymap Functions):
+ Document the new command remapping functionality in this file.</pre>
+
+ <h2>ChangeLog Entries from <a name="modules:ChangeLog">modules/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2012-10-15 Mats Lidell <matsl(a)xemacs.org>
+
+ * common/Makefile.common (distclean): Don't delete configure.</pre>
+
+ <h2>ChangeLog Entries from <a name="nt:ChangeLog">nt/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.</pre>
+
+ <h2>ChangeLog Entries from <a name="src:ChangeLog">src/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2012-12-24 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ (Fself_insert_command): Oops, Aidan renamed make_int to make_fixnum.
+ Adjust my patch to match. Thank you, Mr. Buildbot (and matsl! :-)
+
+2012-12-24 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * cmds.c (Fself_insert_command):
+ Allow noninteractive call with null argument.
+
+2012-12-24 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ Based on patch by Benson and Steven Mitchell on XEmacs Beta
+ <50D16FF7.4090708(a)bnin.net>.
+
+ * sequence.c (venn): Fix bug in handling null arguments.
+ Add null set short circuits, conditional on caller is `subsetp'.
+
+2012-10-18 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * fontcolor-xlike-inc.c (xft_find_charset_font):
+ Improve charset not in table warning message.
+
+2012-11-06 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * keymap.c (define_key_check_and_coerce_keysym):
+ When worrying about GNU Emacs-like keysym syntax, if the symbol
+ name starts with c-whatever (or s-whatever, or m-whatever), check
+ for a function binding for that before erroring. Otherwise command
+ remapping and C mode interact badly, since most of the C mode
+ commands are regarded as GNU Emacs-style keysyms.
+
+2012-11-06 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * keymap.c (event_binding):
+ Do command remapping here for interactive lookups; avoids a
+ relatively expensive repeated call to get_relevant_keymaps(), as
+ was necessary in 7371081ce8f7 (which changeset has been backed
+ out).
+
+2012-10-14 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ Respect face and display table information in the minibuffer
+ prompt. Thanks for the bug report, Nelson Ferreira!
+ * redisplay.c (struct prop_block):
+ Add entries representing the minibuffer prompt explicitly to the
+ union here.
+ * redisplay.c (add_propagation_runes):
+ Respect the face and the display table for the minibuffer prompt
+ here.
+ * redisplay.c (regenerate_window):
+ Use the new union members when passing the minibuffer prompt info
+ to add_propagation_runes().
+
+2012-09-16 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * editfns.c (Fformat_time_string):
+ Accept GNU's UNIVERSAL argument, which means we call gmtime()
+ instead of localtime(). Thanks for the report of org-mode
+ incompatibility, Matsl!
+
+2012-09-07 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * file-coding.c:
+ * file-coding.c (snarf_coding_system):
+ Take a new parameter, FIND_CODING_SYSTEM_P, which indicates that
+ find_coding_system() should be called.
+ * file-coding.c (look_for_coding_system_magic_cookie):
+ * file-coding.c (determine_real_coding_system):
+ * file-coding.c (undecided_convert):
+ Use this parameter.
+ * file-coding.c (Ffind_coding_system_magic_cookie_in_file):
+ New, moved from files.el, so we can use
+ look_for_coding_system_magic_cookie's implementation.
+ * file-coding.c (syms_of_file_coding):
+ Make Ffind_coding_system_magic_cookie_in_file available.
+
+2012-09-05 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * keymap.c:
+ * keymap.c (Fdefine_key):
+ * keymap.c (remap_command):
+ * keymap.c (Fremap_command):
+ Don't sanity-check commands to be remapped with the (define-key
+ KEYMAP [remap COMMAND1] COMMAND2) syntax, for better compatibility
+ with GNU Emacs. Thank you Robert Pluim!
+
+2012-09-02 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * regex.c (re_search_2):
+ * regex.c (re_match_2):
+ If the mirror syntax table is dirty, update it before the search,
+ preventing a malloc() inside the search code, something which
+ isn't allowed. Thank you Henry Thompson!
+
+2012-08-12 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * specifier.c (define_specifier_tag):
+ GC protect the list that Fcharset_list () gave back, it's freshly
+ consed.
+ Clear the alist entries for this tag in CHARSET's tag list if the
+ charset_predicate is nil, so re-creating a charset tag works more
+ effectively.
+ * specifier.c (Fdefine_specifier_tag):
+ Device-type-specific tags *are* available, even if that device
+ type isn't; see specifier.el.
+
+2012-08-06 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * lread.c (read1):
+ * print.c (print_symbol):
+ Adopt GNU's ## syntax for the interned symbol with the zero-length
+ name.
+
+2012-09-02 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * keymap.c:
+ Add command remapping, a more robust equivalent to
+ #'substitute-key-definition.
+ * keymap.c (CHECK_REMAPPING_POSITION): New.
+ * keymap.c (keymap_equal): Correct a comment here.
+ * keymap.c (Fdefine_key): Document the command remapping syntax.
+ * keymap.c (Fremap_command): New.
+ * keymap.c (command_remapping): New.
+ * keymap.c (Fcommand_remapping): New.
+ * keymap.c (commands_remapped_to_mapper): New.
+ * keymap.c (commands_remapped_to_traverser): New.
+ * keymap.c (Fcommands_remapped_to): New.
+ * keymap.c (get_relevant_keymaps): Take a new POSITION argument.
+ * keymap.c (Fcurrent_keymaps, event_binding):
+ Supply the new POSITION argument to get_relevant_keymaps.
+ * keymap.c (Fkey_binding):
+ Add new arguments, NO-REMAP and POSITION.
+
+ * keymap.c (map_keymap_mapper):
+ * keymap.c (Fwhere_is_internal):
+ * keymap.c (where_is_to_char):
+ * keymap.c (where_is_recursive_mapper):
+ Don't expose the key remapping in these functions. This conflicts
+ with GNU, but is more sane for our callers. Access to command
+ remapping is with the functions #'command-remapping,
+ #'commands-remapped-to, and #'remap-command, not with the general
+ keymap functions, apart from the compatibility hack in #'define-key.
+
+ * keymap.c (syms_of_keymap):
+ * keymap.c (vars_of_keymap):
+ * keymap.c (complex_vars_of_keymap):
+ * lisp.h: New CHECK_COMMAND macro.</pre>
+
+ <h2>ChangeLog Entries from <a name="tests:ChangeLog">tests/ChangeLog</a></h2>
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+ <pre xml:space="preserve">
+
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
+2012-12-19 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * automated/lisp-tests.el: Add tests of #'subsetp.
+ Thanks Steven and Benson Mitchell <smitchell(a)bnin.net>.
+
+2012-12-14 Mats Lidell <matsl(a)xemacs.org>
+
+ * automated/register-tests.el: New. Test for register.el. Test
+ case for bug in regular expression in describe-register-1
+
+2012-10-13 Mats Lidell <matsl(a)xemacs.org>
+
+ * automated/process-tests.el: Simple test cases for
+ call-process-shell-command.
+
+2012-09-02 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * automated/regexp-tests.el:
+ Make sure we can search for character ranges successfully when the
+ syntax table is dirty.
+
+2012-09-02 Aidan Kehoe <kehoea(a)parhasard.net>
+
+ * automated/keymap-tests.el:
+ Test the new command remapping functionality.</pre>
+
+ <p>goto <a href="#announcement">announcement</a>,
+ <a href="#summary">summary</a>,
+ <a href="#changes">changes</a></p>
+
+<!-- Keep this comment at the end of the file
+Local variables:
+mode: xml
+sgml-omittag:nil
+sgml-shorttag:nil
+sgml-namecase-general:nil
+sgml-general-insert-case:lower
+sgml-minimize-attributes:nil
+sgml-always-quote-attributes:t
+sgml-indent-step:2
+sgml-indent-data:t
+sgml-parent-document:("../template.html" "html" "body" "table" "tr" "td")
+sgml-exposed-tags:nil
+sgml-local-catalogs:nil
+sgml-local-ecat-files:nil
+End:
+-->
diff -r 09422ac55723e3570603f1cc304642289dd21dd0 -r 7ed89624423a0e658cd4313aba8a71acb5f37db2 Releases/index.content
--- a/Releases/index.content
+++ b/Releases/index.content
@@ -228,6 +228,8 @@
</p><ul>
+ <li><strong>2012-01-04</strong>: <a href="21.5.33.html">[21.5.33 release notice]</a><a href="21.5.33.html#changes">[changelogs]</a></li>
+ <li><strong>2012-08-02</strong>: <a href="21.5.32.html">[21.5.32 release notice]</a><a href="21.5.32.html#changes">[changelogs]</a></li><li><strong>2011-04-29</strong>: <a href="21.5.31.html">[21.5.31 release notice]</a><a href="21.5.31.html#changes">[changelogs]</a></li><li><strong>2011-04-27</strong>: <a href="21.5.30.html">[21.5.30 release notice]</a><a href="21.5.30.html#changes">[changelogs]</a></li><li><strong>2009-05-19</strong>: <a href="21.5.29.html">[21.5.29 release notice]</a><a href="21.5.29.html#changes">[changelogs]</a></li>
diff -r 09422ac55723e3570603f1cc304642289dd21dd0 -r 7ed89624423a0e658cd4313aba8a71acb5f37db2 index.content
--- a/index.content
+++ b/index.content
@@ -79,7 +79,7 @@
<dt><strong><a href="<!-- _GP_ relPath(qq{Releases/index.html#Stable}) -->">Stable</a> branch:</strong></dt><dd><a href="Releases/21.4.22.html">21.4.22</a></dd><dt><strong><a href="<!-- _GP_ relPath(qq{Releases/index.html#Beta}) -->">Beta</a> branch:</strong></dt>
- <dd><a href="Releases/21.5.32.html">21.5.32</a></dd>
+ <dd><a href="Releases/21.5.33.html">21.5.33</a></dd></dl><ul>
Repository URL: https://bitbucket.org/xemacs/xemacsweb/
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://lists.xemacs.org/mailman/listinfo/xemacs-patches
commit/XEmacs: 4 new changesets
11 years, 11 months
Bitbucket
4 new commits in XEmacs:
https://bitbucket.org/xemacs/xemacs/commits/b953a6ce2635/
changeset: b953a6ce2635
user: stephen_at_xemacs
date: 2013-01-04 12:46:30
summary: Prep 21.5.33.
affected #: 1 file
diff -r 93d231ffa106273a4861245b2960404d3e228164 -r b953a6ce2635c82cfa878ce4c48a2973eb912bcf CHANGES-beta
--- a/CHANGES-beta
+++ b/CHANGES-beta
@@ -1,5 +1,56 @@
# DO NOT PUT A VERSION MARKER HERE, ADDED AT RELEASE
+Major Features, Bugfixes, and Backward Incompatible Changes
+
+-- Nothing major this time.
+
+User-Visible Bug Fixes and Improvements
+
+-- Fix: Implement :active in submenu specs. -- Byrel Mitchell
+-- Improve: Reorganize default menubar. -- Stephen J. Turnbull
+
+Build Infrastructure and Source Tree
+
+-- Fix: Prevent make distclean from deleting configure in modules. -- Mats Lidell
+-- Improve: Make configure warn about missing system package hierarchies. -- Stephen J. Turnbull
+
+Documentation
+
+-- Fix: Description of Mercurial repositories. -- Stephen J. Turnbull
+-- Fix: TUTORIAL to describe recenter-top-bottom correctly. -- Mats Lidell
+-- Improve: Description of `mark-defun'. -- Steven Mitchell
+-- Improve: Documentation of menus. -- Byrel Mitchell, Vin Shelton
+-- Improve: INSTALL. -- Steven Mitchell, Stephen J. Turnbull, Robert D. Royar
+
+Lisp API
+
+-- New: Adopt GNU's ## syntax for the interned symbol with the zero-length name. -- Aidan Kehoe
+-- New: Command remapping in keymaps from GNU. -- Aidan Kehoe
+-- New: call-process-shell-command from GNU. -- Mats Lidell
+-- New: delete-trailing-lines, delete-trailing-whitespace from GNU. -- Aidan Kehoe
+-- New: recenter-positions, recenter-top-bottom, recenter-last-op from GNU. -- Mats Lidell
+-- Improve: Accept GNU's UNIVERSAL argument in format-time-string. -- Aidan Kehoe
+-- Improve: Allow noninteractive call of self-insert-command with null count. -- Stephen J. Turnbull
+
+Internal API and Implementation
+
+-- Fix: Avoid malloc'ing inside search. -- Aidan Kehoe
+-- Fix: GCPRO etc in define-specifier-tag. -- Aidan Kehoe
+-- Fix: Incorrect handling of empty sets in subsetp. -- Stephen J. Turnbull, Benson Mitchell, Steven Mitchell
+-- Fix: Inhibit error at compile time in equal, member, assoc, rassoc. -- Aidan Kehoe
+-- Fix: Regexp in describe-register-1. -- Stephen Turnbull, Mats Lidell
+-- Fix: Respect face and display table information in the minibuffer prompt. -- Aidan Kehoe
+-- Improve: Charset not in table warning message. -- Stephen J. Turnbull
+-- Improve: find-coding-system-magic-cookie-in-file moved to C. -- Aidan Kehoe
+
+Testing and Debugging
+
+-- New: Simple test cases for call-process-shell-command. -- Mats Lidell
+-- New: Test regular expression in describe-register-1. -- Mats Lidell
+-- New: Test search for character ranges with dirty syntax table. -- Aidan Kehoe
+-- New: Test the new command remapping functionality. -- Aidan Kehoe
+-- New: Tests of #'subsetp. -- Stephen J. Turnbull, Steven Mitchell, Benson Mitchell
+
to XEmacs 21.5.32 "habanero"
Major Features, Bugfixes, and Backward Incompatible Changes
https://bitbucket.org/xemacs/xemacs/commits/99e10b10008c/
changeset: 99e10b10008c
user: stephen_at_xemacs
date: 2013-01-04 17:35:58
summary: Minor reordering of CHANGES.
affected #: 1 file
diff -r b953a6ce2635c82cfa878ce4c48a2973eb912bcf -r 99e10b10008cedb631ca60aca8ee2d994c195f3c CHANGES-beta
--- a/CHANGES-beta
+++ b/CHANGES-beta
@@ -1,12 +1,13 @@
# DO NOT PUT A VERSION MARKER HERE, ADDED AT RELEASE
+to XEmacs 21.5.33 "horseradish"
+
Major Features, Bugfixes, and Backward Incompatible Changes
--- Nothing major this time.
+-- Nothing major this time. -- nobody
User-Visible Bug Fixes and Improvements
--- Fix: Implement :active in submenu specs. -- Byrel Mitchell
-- Improve: Reorganize default menubar. -- Stephen J. Turnbull
Build Infrastructure and Source Tree
@@ -24,6 +25,7 @@
Lisp API
+-- Fix: Implement :active in submenu specs. -- Byrel Mitchell
-- New: Adopt GNU's ## syntax for the interned symbol with the zero-length name. -- Aidan Kehoe
-- New: Command remapping in keymaps from GNU. -- Aidan Kehoe
-- New: call-process-shell-command from GNU. -- Mats Lidell
https://bitbucket.org/xemacs/xemacs/commits/bee2e2568828/
changeset: bee2e2568828
user: stephen_at_xemacs
date: 2013-01-04 18:11:22
summary: XEmacs 21.5.33 "horseradish" is released.
affected #: 12 files
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 ChangeLog
--- a/ChangeLog
+++ b/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-12-27 Robert D. Royar <xemacs(a)royar.org>
Minor additions by Stephen J. Turnbull <stephen(a)xemacs.org>.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 etc/ChangeLog
--- a/etc/ChangeLog
+++ b/etc/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-09-18 Mats Lidell <matsl(a)xemacs.org>
* TUTORIAL: Updated due to recenter-top-bottom
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 lib-src/ChangeLog
--- a/lib-src/ChangeLog
+++ b/lib-src/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-08-02 Stephen J. Turnbull <stephen(a)xemacs.org>
* XEmacs 21.5.32 "habanero" is released.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 lisp/ChangeLog
--- a/lisp/ChangeLog
+++ b/lisp/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-12-28 Byrel Mitchell <byrel.mitchell(a)gmail.com>
* menubar.el (check-menu-syntax): Implement :active in submenu specs.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 lwlib/ChangeLog
--- a/lwlib/ChangeLog
+++ b/lwlib/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-08-02 Stephen J. Turnbull <stephen(a)xemacs.org>
* XEmacs 21.5.32 "habanero" is released.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 man/ChangeLog
--- a/man/ChangeLog
+++ b/man/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2013-01-02 Vin Shelton <acs(a)xemacs.org>
* lispref/menus.texi (Creating Menu Accelerators): Clarify that
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 modules/ChangeLog
--- a/modules/ChangeLog
+++ b/modules/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-10-15 Mats Lidell <matsl(a)xemacs.org>
* common/Makefile.common (distclean): Don't delete configure.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 nt/ChangeLog
--- a/nt/ChangeLog
+++ b/nt/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-08-02 Stephen J. Turnbull <stephen(a)xemacs.org>
* XEmacs 21.5.32 "habanero" is released.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 src/ChangeLog
--- a/src/ChangeLog
+++ b/src/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-12-24 Stephen J. Turnbull <stephen(a)xemacs.org>
(Fself_insert_command): Oops, Aidan renamed make_int to make_fixnum.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 src/depend
--- a/src/depend
+++ b/src/depend
@@ -147,7 +147,7 @@
events.o: $(CONFIG_H) $(LISP_H) buffer.h bufslots.h casetab.h charset.h chartab.h conslots.h console-impl.h console-tty-impl.h console-tty.h console.h device.h events.h extents.h frame-impl.h frame.h frameslots.h glyphs.h keymap-buttons.h keymap.h lstream.h redisplay.h scrollbar.h specifier.h systime.h systty.h toolbar.h window-impl.h window.h winslots.h
extents.o: $(CONFIG_H) $(LISP_H) backtrace.h buffer.h bufslots.h casetab.h charset.h chartab.h console.h debug.h device.h elhash.h extents-impl.h extents.h faces.h frame.h glyphs.h gutter.h insdel.h keymap-buttons.h keymap.h opaque.h process.h profile.h redisplay.h scrollbar.h specifier.h window-impl.h window.h winslots.h
faces.o: $(CONFIG_H) $(LISP_H) buffer.h bufslots.h casetab.h charset.h chartab.h conslots.h console-impl.h console.h device-impl.h device.h devslots.h elhash.h extents-impl.h extents.h faces.h fontcolor-impl.h fontcolor.h frame-impl.h frame.h frameslots.h glyphs.h redisplay.h scrollbar.h specifier.h window-impl.h window.h winslots.h
-file-coding.o: $(CONFIG_H) $(LISP_H) buffer.h bufslots.h casetab.h charset.h chartab.h coding-system-slots.h elhash.h extents.h file-coding.h insdel.h lstream.h opaque.h rangetab.h
+file-coding.o: $(CONFIG_H) $(LISP_H) buffer.h bufslots.h casetab.h charset.h chartab.h coding-system-slots.h elhash.h extents.h file-coding.h insdel.h intl-auto-encap-win32.h lstream.h opaque.h rangetab.h sysfile.h syswindows.h
fileio.o: $(CONFIG_H) $(LISP_H) backtrace.h buffer.h bufslots.h casetab.h charset.h chartab.h coding-system-slots.h console.h device.h events.h file-coding.h frame.h insdel.h intl-auto-encap-win32.h keymap-buttons.h lstream.h ndir.h process.h profile.h redisplay.h scrollbar.h sysdep.h sysdir.h sysfile.h sysproc.h syspwd.h syssignal.h systime.h syswindows.h window-impl.h window.h winslots.h
filelock.o: $(CONFIG_H) $(LISP_H) buffer.h bufslots.h casetab.h charset.h chartab.h intl-auto-encap-win32.h ndir.h paths.h sysdir.h sysfile.h sysproc.h syspwd.h syssignal.h systime.h syswindows.h
filemode.o: $(CONFIG_H) $(LISP_H) intl-auto-encap-win32.h sysfile.h syswindows.h
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 tests/ChangeLog
--- a/tests/ChangeLog
+++ b/tests/ChangeLog
@@ -1,3 +1,7 @@
+2013-01-04 Stephen J. Turnbull <stephen(a)xemacs.org>
+
+ * XEmacs 21.5.33 "horseradish" is released.
+
2012-12-19 Stephen J. Turnbull <stephen(a)xemacs.org>
* automated/lisp-tests.el: Add tests of #'subsetp.
diff -r 99e10b10008cedb631ca60aca8ee2d994c195f3c -r bee2e2568828468be3b89975ccd953c62b315134 version.sh.in
--- a/version.sh.in
+++ b/version.sh.in
@@ -2,11 +2,11 @@
emacs_is_beta=t
emacs_major_version=21
emacs_minor_version=5
-emacs_beta_version=32
-xemacs_codename="habanero"
+emacs_beta_version=33
+xemacs_codename="horseradish"
emacs_kit_version=
infodock_major_version=
infodock_minor_version=
infodock_build_version=
-xemacs_release_date="2012-08-03"
+xemacs_release_date="2013-01-05"
xemacs_extra_name=
\ No newline at end of file
https://bitbucket.org/xemacs/xemacs/commits/8b5bdc8aebfd/
changeset: 8b5bdc8aebfd
user: stephen_at_xemacs
date: 2013-01-04 18:11:23
summary: Added tag r21-5-33 for changeset bee2e2568828
affected #: 1 file
diff -r bee2e2568828468be3b89975ccd953c62b315134 -r 8b5bdc8aebfd835411a42e614d2ef41fe4b51a1c .hgtags
--- a/.hgtags
+++ b/.hgtags
@@ -248,3 +248,4 @@
900a0a8796c3ed061d162891e3af01040b78901d r21-5-32
384423af8fb5267509e2450f9eebc3dfaeda8472 r21-5-latest-beta
900a0a8796c3ed061d162891e3af01040b78901d r21-5-latest-beta
+bee2e2568828468be3b89975ccd953c62b315134 r21-5-33
Repository URL: https://bitbucket.org/xemacs/xemacs/
diff -r e6f8eb00235954a871e6f44c161e09d34cd2af69 -r ea4257fccf9b3cbe323b3b04323c083096dabd70 cc-engine.el
--- a/cc-engine.el
+++ b/cc-engine.el
@@ -2463,8 +2463,12 @@
;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;;
;; Variables which keep track of preprocessor constructs.
+(defvar c-state-old-cpp-beg-marker nil)
+(make-variable-buffer-local 'c-state-old-cpp-beg-marker)
(defvar c-state-old-cpp-beg nil)
(make-variable-buffer-local 'c-state-old-cpp-beg)
+(defvar c-state-old-cpp-end-marker nil)
+(make-variable-buffer-local 'c-state-old-cpp-end-marker)
(defvar c-state-old-cpp-end nil)
(make-variable-buffer-local 'c-state-old-cpp-end)
;; These are the limits of the macro containing point at the previous call of
@@ -2573,8 +2577,11 @@
start-point cache-pos)))
;; Might we be better off starting from the top level, two defuns back,
- ;; instead?
- (when (> how-far c-state-cache-too-far)
+ ;; instead? This heuristic no longer works well in C++, where
+ ;; declarations inside namespace brace blocks are frequently placed at
+ ;; column zero.
+ (when (and (not (c-major-mode-is 'c++-mode))
+ (> how-far c-state-cache-too-far))
(setq BOD-pos (c-get-fallback-scan-pos here)) ; somewhat EXPENSIVE!!!
(if (< (- here BOD-pos) how-far)
(setq strategy 'BOD
@@ -2649,29 +2656,40 @@
;; reduce the time wasted in repeated fruitless searches in brace deserts.
(save-excursion
(save-restriction
- (let ((bra from) ce ; Positions of "{" and "}".
- new-cons
- (cache-pos (c-state-cache-top-lparen)) ; might be nil.
- (macro-start-or-from
- (progn (goto-char from)
- (c-beginning-of-macro)
- (point))))
+ (let* (new-cons
+ (cache-pos (c-state-cache-top-lparen)) ; might be nil.
+ (macro-start-or-from
+ (progn (goto-char from)
+ (c-beginning-of-macro)
+ (point)))
+ (bra ; Position of "{".
+ ;; Don't start scanning in the middle of a CPP construct unless
+ ;; it contains HERE - these constructs, in Emacs, are "commented
+ ;; out" with category properties.
+ (if (eq (c-get-char-property macro-start-or-from 'category)
+ 'c-cpp-delimiter)
+ macro-start-or-from
+ from))
+ ce) ; Position of "}"
(or upper-lim (setq upper-lim from))
;; If we're essentially repeating a fruitless search, just give up.
(unless (and c-state-brace-pair-desert
(eq cache-pos (car c-state-brace-pair-desert))
+ (or (null (car c-state-brace-pair-desert))
+ (> from (car c-state-brace-pair-desert)))
(<= from (cdr c-state-brace-pair-desert)))
- ;; DESERT-LIM. Only search what we absolutely need to,
+ ;; DESERT-LIM. Avoid repeated searching through the cached desert.
(let ((desert-lim
(and c-state-brace-pair-desert
(eq cache-pos (car c-state-brace-pair-desert))
+ (>= from (cdr c-state-brace-pair-desert))
(cdr c-state-brace-pair-desert)))
;; CACHE-LIM. This limit will be necessary when an opening
;; paren at `cache-pos' has just had its matching close paren
;; inserted. `cache-pos' continues to be a search bound, even
;; though the algorithm below would skip over the new paren
;; pair.
(cache-lim (and cache-pos (< cache-pos from) cache-pos)))
(narrow-to-region
(cond
@@ -2892,7 +2910,9 @@
(point-max)
(min (point-max) c-state-old-cpp-beg)))
(while (and c-state-cache (>= (c-state-cache-top-lparen) upper-lim))
+ (setq scan-back-pos (car-safe (car c-state-cache)))
(setq c-state-cache (cdr c-state-cache)))
+
;; If `upper-lim' is inside the last recorded brace pair, remove its
;; RBrace and indicate we'll need to search backwards for a previous
;; brace pair.
@@ -3325,6 +3345,13 @@
;; XEmacs
(c-invalidate-state-cache-1 here)))
+(defmacro c-state-maybe-marker (place marker)
+ ;; If PLACE is non-nil, return a marker marking it, otherwise nil.
+ ;; We (re)use MARKER.
+ `(and ,place
+ (or ,marker (setq ,marker (make-marker)))
+ (set-marker ,marker ,place)))
+
(defun c-parse-state ()
;; This is a wrapper over `c-parse-state-1'. See that function for a
;; description of the functionality and return value.
@@ -3356,9 +3383,10 @@
(c-parse-state-1))))
;; XEmacs
(c-parse-state-1))
- (setq c-state-old-cpp-beg (and here-cpp-beg (copy-marker here-cpp-beg t))
- c-state-old-cpp-end (and here-cpp-end (copy-marker here-cpp-end t)))
- )))
+ (setq c-state-old-cpp-beg
+ (c-state-maybe-marker here-cpp-beg c-state-old-cpp-beg-marker)
+ c-state-old-cpp-end
+ (c-state-maybe-marker here-cpp-end c-state-old-cpp-end-marker)))))
;; Debug tool to catch cache inconsistencies. This is called from
;; 000tests.el.
@@ -3367,13 +3395,26 @@
(fset 'c-real-parse-state (symbol-function 'c-parse-state)))
(cc-bytecomp-defun c-real-parse-state)
+(defvar c-parse-state-point nil)
(defvar c-parse-state-state nil)
(make-variable-buffer-local 'c-parse-state-state)
(defun c-record-parse-state-state ()
+ (setq c-parse-state-point (point))
(setq c-parse-state-state
(mapcar
(lambda (arg)
- (cons arg (symbol-value arg)))
+ (let ((val (symbol-value arg)))
+ (cons arg
+
+ ;; (if (consp val)
+ ;; (copy-tree val)
+ ;; val)
+
+ (cond ((consp val) (copy-tree val))
+ ((markerp val) (copy-marker val))
+ (t val))
+
+)))
'(c-state-cache
c-state-cache-good-pos
c-state-nonlit-pos-cache
@@ -3386,16 +3427,31 @@
c-state-point-min-lit-start
c-state-min-scan-pos
c-state-old-cpp-beg
- c-state-old-cpp-end))))
+ c-state-old-cpp-end
+ c-parse-state-point))))
(defun c-replay-parse-state-state ()
(message
(concat "(setq "
(mapconcat
(lambda (arg)
- (format "%s %s%s" (car arg) (if (atom (cdr arg)) "" "'") (cdr arg)))
+ (format "%s %s%s" (car arg)
+ (if (atom (cdr arg)) "" "'")
+ (if (markerp (cdr arg))
+ (format "(copy-marker %s)" (marker-position (cdr arg)))
+ (cdr arg))))
c-parse-state-state " ")
")")))
+(defun c-debug-parse-state-double-cons (state)
+ (let (state-car conses-not-ok)
+ (while state
+ (setq state-car (car state)
+ state (cdr state))
+ (if (and (consp state-car)
+ (consp (car state)))
+ (setq conses-not-ok t)))
+ conses-not-ok))
+
(defun c-debug-parse-state ()
(let ((here (point)) (res1 (c-real-parse-state)) res2)
(let ((c-state-cache nil)
@@ -3428,8 +3484,16 @@
here res1 res2)
(message "Old state:")
(c-replay-parse-state-state))
+
+ (when (c-debug-parse-state-double-cons res1)
+ (message "c-parse-state INVALIDITY at %s: %s"
+ here res1)
+ (message "Old state:")
+ (c-replay-parse-state-state))
+
(c-record-parse-state-state)
- res1))
+ res2 ; res1 correct a cascading series of errors ASAP
+ ))
(defun c-toggle-parse-state-debug (&optional arg)
(interactive "P")
@@ -3437,7 +3501,9 @@
(fset 'c-parse-state (symbol-function (if c-debug-parse-state
'c-debug-parse-state
'c-real-parse-state)))
- (c-keep-region-active))
+ (c-keep-region-active)
+ (message "c-debug-parse-state %sabled"
+ (if c-debug-parse-state "en" "dis")))
(when c-debug-parse-state
(c-toggle-parse-state-debug 1))
@@ -2649,29 +2656,40 @@
;; CACHE-LIM. This limit will be necessary when an opening
;; paren at `cache-pos' has just had its matching close paren
- ;; inserted. `cache-pos' continues to be a search bound, even
- ;; though the algorithm below would skip over the new paren
- ;; pair.
+ ;; inserted into the buffer. `cache-pos' continues to be a
+ ;; search bound, even though the algorithm below would skip
+ ;; over the new paren pair.
(cache-lim (and cache-pos (< cache-pos from) cache-pos)))
(narrow-to-region
--
This is a commit notification from bitbucket.org. You are receiving
this because you have the service enabled, addressing the recipient of
this email.
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://lists.xemacs.org/mailman/listinfo/xemacs-patches
Re: Small documentation error
11 years, 11 months
Vin Shelton
Byrel -
On Wed, Jan 2, 2013 at 4:19 PM, Byrel Mitchell <byrel.mitchell(a)gmail.com> wrote:
> Looks good!
Thanks for the feedback.
>> There remains a bug with the accelerator code - even though the
>> accelerator for "One" is "1", I notice that the initial "O" is
>> underlined.
>>
> This is documented in the lispref, so I'm not sure it quite qualifies
> as a bug: "Menu accelerators are specified as part of the menubar
> format using the :accelerator tag to specify a key or by placing "%_"
> in the menu or menu item name prior to the letter which is to be used
> as the accelerator key. The advantage of the second method is that the
> menu rendering code then knows to draw an underline under that
> character, which is the canonical way of indicating an accelerator key
> to a user. "
Well, in the example code, the "O" is underlined as if it were an
accelerator, but neither "o" nor "O" works as an accelerator. That's
a bug.
Regards,
Vin
_______________________________________________
XEmacs-Patches mailing list
XEmacs-Patches(a)xemacs.org
http://lists.xemacs.org/mailman/listinfo/xemacs-patches